@@ -341,6 +341,18 @@ Returns \"text\" for unrecognized extensions to ensure consistent fencing."
       (or (cdr (assoc ext pi-coding-agent--extension-language-alist))
           "text"))))
 
+;;;; Markdown Escape Fix
+
+(defconst pi-coding-agent--markdown-regex-escape
+  "\\(\\\\\\)[]!\"#$%&'()*+,./:;<=>?@[\\\\^_`{|}~-]"
+  "Restricted version of `markdown-regex-escape' for CommonMark §2.4.
+Markdown-mode's regex matches backslash + ANY character and hides
+the backslash when `markdown-hide-markup' is enabled.  This turns
+\"\\n\" into just \"n\", \"\\t\" into just the letter, etc.  CommonMark
+only defines escapes for ASCII punctuation, so we override the regex
+buffer-locally in `pi-coding-agent-chat-mode' to match only valid
+escape targets.")
+
 ;;;; Major Modes
 
 (defvar pi-coding-agent-chat-mode-map
@@ -505,6 +517,9 @@ This is a read-only buffer showing the conversation history."
   ;; Hide markdown markup (**, `, ```) for cleaner display
   (setq-local markdown-hide-markup t)
   (add-to-invisibility-spec 'markdown-markup)
+  ;; Restrict backslash escapes to CommonMark punctuation only.
+  ;; Without this, \n \t \r etc. lose their backslash in the display.
+  (setq-local markdown-regex-escape pi-coding-agent--markdown-regex-escape)
   ;; Strip hidden markup from copy operations (M-w, C-w)
   (setq-local filter-buffer-substring-function
               #'pi-coding-agent--filter-buffer-substring)
@@ -857,6 +872,28 @@ Extracted from session_info entries when session is loaded or switched.")
 Each entry is a plist with :name, :description, :source.
 Source is \"prompt\", \"extension\", or \"skill\".")
 
+(defvar pi-coding-agent--builtin-commands
+  '(("compact" :handler pi-coding-agent-compact       :args optional)
+    ("new"     :handler pi-coding-agent-new-session)
+    ("model"   :handler pi-coding-agent-select-model  :args optional)
+    ("session" :handler pi-coding-agent-session-stats)
+    ("name"    :handler pi-coding-agent-set-session-name :args required)
+    ("fork"    :handler pi-coding-agent-fork)
+    ("resume"  :handler pi-coding-agent-resume-session)
+    ("reload"  :handler pi-coding-agent-reload)
+    ("export"  :handler pi-coding-agent-export-html  :args optional)
+    ("copy"    :handler pi-coding-agent-copy-last-message)
+    ("quit"    :handler pi-coding-agent-quit))
+  "Built-in slash commands dispatched client-side.
+Each entry is (NAME . PLIST) where PLIST has:
+  :handler  Function to call (symbol)
+  :args     nil (no args), `optional', or `required'
+
+Commands with :args `optional' pass the trailing text (or nil) to the
+handler.  Commands with :args `required' prompt interactively when no
+argument is given (the handler's `interactive' spec handles this).
+Descriptions come from the handler's docstring.")
+
 (defun pi-coding-agent--set-commands (commands)
   "Set COMMANDS in current buffer and propagate to sibling session buffers.
 COMMANDS is a list of plists with :name, :description, :source.
